==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/ListThingsInBillingGroupResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.{NextToken, ThingName}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListThingsInBillingGroupResponse(
    things: Optional[Iterable[ThingName]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse = {
    import ListThingsInBillingGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse
      .builder()
      .optionallyWith(
        things.map(value =>
          value.map { item =>
            ThingName.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.things)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.ListThingsInBillingGroupResponse.ReadOnly =
    zio.aws.iot.model.ListThingsInBillingGroupResponse.wrap(buildAwsValue())
}
object ListThingsInBillingGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListThingsInBillingGroupResponse =
      zio.aws.iot.model.ListThingsInBillingGroupResponse(
        things.map(value => value),
        nextToken.map(value => value)
      )
    def things: Optional[List[ThingName]]
    def nextToken: Optional[NextToken]
    def getThings: ZIO[Any, AwsError, List[ThingName]] =
      AwsError.unwrapOptionField("things", things)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse
  ) extends zio.aws.iot.model.ListThingsInBillingGroupResponse.ReadOnly {
    override val things: Optional[List[ThingName]] = zio.aws.core.internal
      .optionalFromNullable(impl.things())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iot.model.primitives.ThingName(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse
  ): zio.aws.iot.model.ListThingsInBillingGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iot_3-5.17.148.1-sources.jar: zio/aws/iot/model/ListThingsInBillingGroupResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.{NextToken, ThingName}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListThingsInBillingGroupResponse(
    things: Option[Iterable[ThingName]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse = {
    import ListThingsInBillingGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse
      .builder()
      .optionallyWith(
        things.map(value =>
          value.map { item =>
            ThingName.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.things)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.ListThingsInBillingGroupResponse.ReadOnly =
    zio.aws.iot.model.ListThingsInBillingGroupResponse.wrap(buildAwsValue())
}
object ListThingsInBillingGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListThingsInBillingGroupResponse =
      zio.aws.iot.model.ListThingsInBillingGroupResponse(
        things.map(value => value),
        nextToken.map(value => value)
      )
    def things: Option[List[ThingName]]
    def nextToken: Option[NextToken]
    def getThings: ZIO[Any, AwsError, List[ThingName]] =
      AwsError.unwrapOptionField("things", things)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse
  ) extends zio.aws.iot.model.ListThingsInBillingGroupResponse.ReadOnly {
    override val things: Option[List[ThingName]] = scala
      .Option(impl.things())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iot.model.primitives.ThingName(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListThingsInBillingGroupResponse
  ): zio.aws.iot.model.ListThingsInBillingGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}
